@@ -35,7 +35,7 @@ def any_public_tests(test_cases):
     Returns whether any of the ``Test`` named tuples in ``test_cases`` are public tests.
 
     Args:
-        test_cases (``list`` of ``Test``): list of test cases
+        test_cases (``list`` of ``Test`` or ``OttrTest``): list of test cases
     
     Returns:
         ``bool``: whether any of the tests are public
@@ -86,6 +86,14 @@ def gen_test_cell(question, tests, tests_dict, assignment):
 
     suites = [gen_suite(tests)]
     points = question.get('points', 1)
+    if isinstance(points, dict):
+        points = points.get('each', 1) * len(suites[0]['cases'])
+    elif isinstance(points, list):
+        if len(points) != len(tests):
+            raise ValueError(
+                f"Error in question {question['name']}: length of 'points' is {len(points)} but there "
+                f"are {len(tests)} tests"
+            )
     
     test = {
         'name': question['name'],
@@ -174,4 +182,6 @@ def remove_hidden_tests_from_dir(test_dir, assignment):
             for i, case in list(enumerate(suite['cases']))[::-1]:
                 if case['hidden']:
                     suite['cases'].pop(i)
+                    if isinstance(test['points'], list):
+                        test['points'].pop(i)
         write_test(f, test)
