@@ -10,6 +10,7 @@ import re
 import zipfile
 import pickle
 import time
+import warnings
 import datetime as dt
 
 from getpass import getpass
@@ -19,8 +20,10 @@ from IPython import get_ipython
 from IPython.display import display, HTML, Javascript
 
 from .logs import LogEntry, EventType, Log
+from .utils import save_notebook
 from ..execute import check
 from ..export import export_notebook
+from ..plugins import PluginCollection
 # from .utils import wait_for_save
 
 _API_KEY = None
@@ -43,13 +46,13 @@ class TestsDisplay:
     def __repr__(self):
         ret = ""
         for name, result in zip(self.test_names, self.results):
-            ret += f"{name}:\n{repr(result)}\n\n"
+            ret += f"{repr(result)}\n\n"
         return ret
 
     def _repr_html_(self):
         ret = ""
         for name, result in zip(self.test_names, self.results):
-            ret += f"<p><strong>{name}:</strong></p>\n{result._repr_html_()}\n\n"
+            ret += f"{result._repr_html_()}\n\n"
         return ret
 
 
@@ -59,18 +62,26 @@ class Notebook:
     Notebook class for in-notebook autograding
 
     Args:
+        nb_path(``str``, optional): path to the notebook being run
         test_dir (``str``, optional): path to tests directory
     """
 
-    def __init__(self, test_dir="./tests"):
+    # overrides test_dir arg in __init__, used for changing tests dir during grading
+    _tests_dir_override = None
+
+    def __init__(self, nb_path=None, test_dir="./tests"):
         try:
             global _API_KEY, _SHELVE
             # assert os.path.isdir(test_dir), "{} is not a directory".format(test_dir)
 
-            self._path = test_dir
+            if type(self)._tests_dir_override is not None:
+                self._path = type(self)._tests_dir_override
+            else:
+                self._path = test_dir
             self._service_enabled = False
-            self._notebook = None
-
+            self._notebook = nb_path
+            self._addl_files = []
+            self._plugin_collections = {}
 
             # assume using otter service if there is a .otter file
             otter_configs = glob("*.otter")
@@ -87,13 +98,6 @@ class Notebook:
                 self._ignore_modules = self._config.get("ignore_modules", [])
                 self._vars_to_store = self._config.get("variables", None)
 
-
-
-                # if "notebook" not in self._config:
-                #     assert len(glob("*.ipynb")) == 1, "Notebook not specified in otter config file"
-                #     self._notebook = glob("*.ipynb")[0]
-
-                # else:
                 self._notebook = self._config["notebook"]
 
                 if self._service_enabled:
@@ -165,7 +169,6 @@ class Notebook:
         else:
             self._log_event(EventType.AUTH)
 
-
     def _log_event(self, event_type, results=[], question=None, success=True, error=None, shelve_env={}):
         """
         Logs an event
@@ -197,6 +200,34 @@ class Notebook:
 
         entry.flush_to_file(_OTTER_LOG_FILENAME)
 
+    def _resolve_nb_path(self, nb_path):
+        """
+        Attempts to resolve the path to the notebook being run. If ``nb_path`` is ``None``, ``self._notebook``
+        is checked, then the working directory is searched for `.ipynb` files. If none are found, or 
+        more than one is found, a ``ValueError`` is raised.
+
+        Args:
+            nb_path (``Optional[str]``): path to the notebook
+        
+        Returns:
+            ``str``: resolved notebook path
+        
+        Raises:
+            ``ValueError``: if no notebooks or too many notebooks are found.
+        """
+        if nb_path is None and self._notebook is not None:
+            nb_path = self._notebook
+
+        elif nb_path is None and glob("*.ipynb"):
+            notebooks = glob("*.ipynb")
+            assert len(notebooks) == 1, "nb_path not specified and > 1 notebook in working directory"
+            nb_path = notebooks[0]
+
+        elif nb_path is None:
+            raise ValueError("nb_path is None and no otter-service config is available")
+
+        return nb_path
+
     def check(self, question, global_env=None):
         """
         Runs tests for a specific question against a global environment. If no global environment
@@ -231,31 +262,52 @@ class Notebook:
 
         return result
 
-
-    # @staticmethod
-    def to_pdf(self, nb_path=None, filtering=True, pagebreaks=True, display_link=True):
+    def run_plugin(self, plugin_name, *args, nb_path=None, **kwargs):
         """
-        Exports a notebook to a PDF. ``filter_type`` can be ``"html"`` or ``"tags"`` if filtering by
-        HTML comments or cell tags, respectively.
+        Runs the plugin ``plugin_name`` with the specified arguments. Use ``nb_path`` if the path
+        to the notebook is not configured.
 
         Args:
-            nb_path (``str``): Path to iPython notebook we want to export
-            filtering (``bool``, optional): Set true if only exporting a subset of nb cells to PDF
-            pagebreaks (``bool``, optional): If true, pagebreaks are included between questions
-            display_link (``bool``, optional): Whether or not to display a download link
+            plugin_name (``str``): importable name of an Otter plugin that implements the 
+                ``from_notebook`` hook
+            *args: arguments to be passed to the plugin
+            nb_path (``str``, optional): path to the notebook
+            **kwargs: keyword arguments to be passed to the plugin
+
+        """
+        nb_path = self._resolve_nb_path(nb_path)
+        if plugin_name in self._plugin_collections:
+            pc = self._plugin_collections[plugin_name]
+        else:
+            pc = PluginCollection([plugin_name], nb_path, {})
+            self._plugin_collections[plugin_name] = pc
+        pc.run("from_notebook", *args, **kwargs)
+
+    # @staticmethod
+    def to_pdf(self, nb_path=None, filtering=True, pagebreaks=True, display_link=True, force_save=False):
+        """
+        Exports a notebook to a PDF using Otter Export
+
+        Args:
+            nb_path (``str``, optional): path to the notebook we want to export; will attempt to infer
+                if not provided
+            filtering (``bool``, optional): set true if only exporting a subset of notebook cells to PDF
+            pagebreaks (``bool``, optional): if true, pagebreaks are included between questions
+            display_link (``bool``, optional): whether or not to display a download link
+            force_save (``bool``, optional): whether or not to display JavaScript that force-saves the
+                notebook (only works in Jupyter Notebook classic, not JupyterLab)
         """
         # self._save_notebook()
         try:
-            if nb_path is None and self._notebook is not None:
-                nb_path = self._notebook
+            nb_path = self._resolve_nb_path(nb_path)
 
-            elif nb_path is None and glob("*.ipynb"):
-                notebooks = glob("*.ipynb")
-                assert len(notebooks) == 1, "nb_path not specified and > 1 notebook in working directory"
-                nb_path = notebooks[0]
-
-            elif nb_path is None:
-                raise ValueError("nb_path is None and no otter-service config is available")
+            if force_save:
+                saved = save_notebook(nb_path)
+                if not saved:
+                    warnings.warn(
+                        "Could not force-save notebook; the results of this call will be based on the last "
+                        "saved version of this notebook."
+                    )
 
             # convert(nb_path, filtering=filtering, filter_type=filter_type)
             export_notebook(nb_path, filtering=filtering, pagebreaks=pagebreaks)
@@ -275,36 +327,63 @@ class Notebook:
         else:
             self._log_event(EventType.TO_PDF)
 
-
-    def export(self, nb_path=None, export_path=None, pdf=True, filtering=True, pagebreaks=True, files=[], display_link=True):
+    def add_plugin_files(self, plugin_name, *args, nb_path=None, **kwargs):
         """
-        Exports a submission to a zipfile. Creates a submission zipfile from a notebook at ``nb_path``,
+        Runs the ``notebook_export`` event of the plugin ``plugin_name`` and tracks the file paths
+        it returns to be included when calling ``Notebook.export``.
+
+        Args:
+            plugin_name (``str``): importable name of an Otter plugin that implements the 
+                ``from_notebook`` hook
+            *args: arguments to be passed to the plugin
+            nb_path (``str``, optional): path to the notebook
+            **kwargs: keyword arguments to be passed to the plugin        
+        """
+        nb_path = self._resolve_nb_path(nb_path)
+        if plugin_name in self._plugin_collections:
+            pc = self._plugin_collections[plugin_name]
+        else:
+            pc = PluginCollection([plugin_name], nb_path, {})
+            self._plugin_collections[plugin_name] = pc
+        addl_files = pc.run("notebook_export", *args, **kwargs)[0]
+        if addl_files is None:
+            return
+        self._addl_files.extend(addl_files)
+
+    def export(self, nb_path=None, export_path=None, pdf=True, filtering=True, pagebreaks=True, files=[], 
+            display_link=True, force_save=False):
+        """
+        Exports a submission to a zip file. Creates a submission zipfile from a notebook at ``nb_path``,
         optionally including a PDF export of the notebook and any files in ``files``.
 
         Args:
-            nb_path (``str``): path to notebook we want to export
-            export_path (``str``, optional): path at which to write zipfile
+            nb_path (``str``, optional): path to the notebook we want to export; will attempt to infer
+                if not provided
+            export_path (``str``, optional): path at which to write zipfile; defaults to notebook's
+                name + ``.zip``
             pdf (``bool``, optional): whether a PDF should be included
             filtering (``bool``, optional): whether the PDF should be filtered; ignored if ``pdf`` is
                 ``False``
             pagebreaks (``bool``, optional): whether pagebreaks should be included between questions
-            files (``list`` of ``str``, optional): paths to other files to include in the zipfile
+                in the PDF
+            files (``list`` of ``str``, optional): paths to other files to include in the zip file
             display_link (``bool``, optional): whether or not to display a download link
+            force_save (``bool``, optional): whether or not to display JavaScript that force-saves the
+                notebook (only works in Jupyter Notebook classic, not JupyterLab)
         """
         self._log_event(EventType.BEGIN_EXPORT)
         # self._save_notebook()
 
         try:
-            if nb_path is None and self._notebook is not None:
-                nb_path = self._notebook
+            nb_path = self._resolve_nb_path(nb_path)
 
-            elif nb_path is None and glob("*.ipynb"):
-                notebooks = glob("*.ipynb")
-                assert len(notebooks) == 1, "nb_path not specified and > 1 notebook in working directory"
-                nb_path = notebooks[0]
-
-            elif nb_path is None:
-                raise ValueError("nb_path is None and no otter-service config is available")
+            if force_save:
+                saved = save_notebook(nb_path)
+                if not saved:
+                    warnings.warn(
+                        "Could not force-save notebook; the results of this call will be based on the last "
+                        "saved version of this notebook."
+                    )
 
             try:
                 with open(nb_path) as f:
@@ -339,6 +418,9 @@ class Notebook:
 
             for file in files:
                 zf.write(file)
+            
+            for file in self._addl_files:
+                zf.write(file)
 
             zf.close()
 
