@@ -5,9 +5,13 @@ Utilities for Otter Grade
 import tempfile
 import tarfile
 import os
+import docker
 import pandas as pd
 
 from contextlib import contextmanager
+from hashlib import md5
+
+OTTER_DOCKER_IMAGE_TAG = "otter-grade"
 
 @contextmanager
 def simple_tar(path):
@@ -103,3 +107,37 @@ def merge_csv(dataframes):
     """
     final_dataframe = pd.concat(dataframes, axis=0, join='inner').sort_index()
     return final_dataframe
+
+def prune_images():
+    """
+    Prunes all Docker images named ``otter-grade``
+    """
+    # this is a fix for travis -- allows overriding docker client version
+    if os.environ.get("OTTER_DOCKER_CLIENT_VERSION") is not None:
+        client = docker.from_env(version=os.environ.get("OTTER_DOCKER_CLIENT_VERSION"))
+    else:
+        client = docker.from_env()
+    
+    images = client.images.list()
+
+    for img in images:
+        if any([OTTER_DOCKER_IMAGE_TAG in t for t in img.tags]):
+            client.images.remove(img.tags[0], force=True)
+
+def generate_hash(path):
+    """
+    Reads in a file and returns an MD5 hash of its contents.
+
+    Args:
+        path (``str``): path to the file that will be read in and hashed
+
+    Returns:
+        ``str``: the hash value of the file
+    """
+    zip_hash = ""
+    m = md5()
+    with open(path, "rb") as f:
+        data = f.read() # read file in chunk and call update on each chunk if file is large.
+        m.update(data)
+        zip_hash = m.hexdigest()
+    return zip_hash
