@@ -12,14 +12,13 @@ from subprocess import PIPE
 from glob import glob
 from unittest.mock import patch
 
-from otter.argparser import get_parser
+# from otter.argparser import get_parser
 from otter.assign import main as assign
 from otter.generate.token import APIClient
+from otter.runner import run_otter
 
 from . import TestCase
 
-parser = get_parser()
-
 TEST_FILES_PATH = "test/test-assign/"
 
 class TestAssign(TestCase):
@@ -42,11 +41,12 @@ class TestAssign(TestCase):
         """
         # run otter assign
         run_assign_args = [
-            "assign", "--no-run-tests", TEST_FILES_PATH + "example.ipynb", TEST_FILES_PATH + "output", "data.csv"
+            "assign", "--no-run-tests", TEST_FILES_PATH + "example.ipynb", TEST_FILES_PATH + "output",
         ]
-        args = parser.parse_args(run_assign_args)
-        args.func = assign
-        args.func(args)
+        # args = parser.parse_args(run_assign_args)
+        # args.func = assign
+        # args.func(args)
+        run_otter(run_assign_args)
 
         self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "example-correct")
 
@@ -55,12 +55,13 @@ class TestAssign(TestCase):
         Checks that otter assign filters and outputs correctly, as well as creates a correct .otter file
         """
         run_assign_args = [
-            "assign", "--no-init-cell", "--no-check-all", TEST_FILES_PATH + "generate-otter.ipynb", 
-            TEST_FILES_PATH + "output", "data.csv"
+            "assign",  TEST_FILES_PATH + "generate-otter.ipynb", 
+            TEST_FILES_PATH + "output",
         ]
-        args = parser.parse_args(run_assign_args)
-        args.func = assign
-        args.func(args)
+        # args = parser.parse_args(run_assign_args)
+        # args.func = assign
+        # args.func(args)
+        run_otter(run_assign_args)
 
         self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "otter-correct")     
 
@@ -69,18 +70,19 @@ class TestAssign(TestCase):
         Checks that otter assign filters and outputs correctly, as well as creates a correct .zip file along with PDFs
         """
         run_assign_args = [
-            "assign", "--no-run-tests", TEST_FILES_PATH + "generate-pdf.ipynb", TEST_FILES_PATH + "output", "data.csv"
+            "assign", "--no-run-tests", TEST_FILES_PATH + "generate-pdf.ipynb", TEST_FILES_PATH + "output",
         ]
-        args = parser.parse_args(run_assign_args)
-        args.func = assign
-        args.func(args)
+        # args = parser.parse_args(run_assign_args)
+        # args.func = assign
+        # args.func(args)
+        run_otter(run_assign_args)
 
         self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "pdf-correct", ignore_ext=[".pdf",".zip"])
         
-        # check gradescope zip file
-        self.check_gradescope_zipfile(
-            TEST_FILES_PATH + "output/autograder/autograder.zip", TEST_FILES_PATH + "pdf-autograder-correct",
-        )
+        # # check gradescope zip file
+        # self.check_gradescope_zipfile(
+        #     TEST_FILES_PATH + "output/autograder/autograder.zip", TEST_FILES_PATH + "pdf-autograder-correct",
+        # )
     
     @patch.object(APIClient,"get_token")
     def test_gradescope_example(self, mocked_client):
@@ -93,17 +95,17 @@ class TestAssign(TestCase):
         mocked_client.return_value = 'token'
         
         run_gradescope_args = [
-            "assign", "--no-run-tests", "--no-check-all", TEST_FILES_PATH + "generate-gradescope.ipynb", 
-            TEST_FILES_PATH + "output", "data.csv"
+            "assign", "--no-run-tests", TEST_FILES_PATH + "generate-gradescope.ipynb", 
+            TEST_FILES_PATH + "output",
         ]
-        args = parser.parse_args(run_gradescope_args)
-        args.func = assign
-        args.func(args)
+        # args = parser.parse_args(run_gradescope_args)
+        # args.func = assign
+        # args.func(args)
+        run_otter(run_gradescope_args)
         
         self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "gs-correct", ignore_ext=[".pdf",".zip"])
 
         # check gradescope zip file
-        
         self.check_gradescope_zipfile(
             TEST_FILES_PATH + "output/autograder/autograder.zip", TEST_FILES_PATH + "gs-autograder-correct",
         )
@@ -114,18 +116,19 @@ class TestAssign(TestCase):
         """
         run_assign_args = [
             "assign", TEST_FILES_PATH + "r-example.ipynb", 
-            TEST_FILES_PATH + "output", "data.csv"
+            TEST_FILES_PATH + "output",
         ]
-        args = parser.parse_args(run_assign_args)
-        args.func = assign
-        args.func(args)
+        # args = parser.parse_args(run_assign_args)
+        # args.func = assign
+        # args.func(args)
+        run_otter(run_assign_args)
 
         self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "r-correct", ignore_ext=[".pdf",".zip"])
         
-        # check gradescope zip file
-        self.check_gradescope_zipfile(
-            TEST_FILES_PATH + "output/autograder/autograder.zip", TEST_FILES_PATH + "r-autograder-correct",
-        )
+        # # check gradescope zip file
+        # self.check_gradescope_zipfile(
+        #     TEST_FILES_PATH + "output/autograder/autograder.zip", TEST_FILES_PATH + "r-autograder-correct",
+        # )
 
     def test_rmd_example(self):
         """
@@ -133,11 +136,12 @@ class TestAssign(TestCase):
         """
         run_assign_args = [
             "assign", TEST_FILES_PATH + "rmd-example.Rmd", 
-            TEST_FILES_PATH + "output", "data.csv"
+            TEST_FILES_PATH + "output",
         ]
-        args = parser.parse_args(run_assign_args)
-        args.func = assign
-        args.func(args)
+        # args = parser.parse_args(run_assign_args)
+        # args.func = assign
+        # args.func(args)
+        run_otter(run_assign_args)
 
         self.assertDirsEqual(TEST_FILES_PATH + "output", TEST_FILES_PATH + "rmd-correct", ignore_ext=[".zip"])
         
@@ -146,8 +150,10 @@ class TestAssign(TestCase):
             TEST_FILES_PATH + "output/autograder/autograder.zip", TEST_FILES_PATH + "rmd-autograder-correct",
         )
 
-    # def tearDown(self):
-    #     # cleanup
-    #     if os.path.exists(TEST_FILES_PATH + "output"):
-    #         shutil.rmtree(TEST_FILES_PATH + "output")
-        
+    def tearDown(self):
+        """
+        Removes assign output
+        """
+        # cleanup
+        if os.path.exists(TEST_FILES_PATH + "output"):
+            shutil.rmtree(TEST_FILES_PATH + "output")
