@@ -14,16 +14,13 @@ from glob import glob
 from unittest.mock import patch, mock_open
 from shutil import copyfile
 
-from otter.argparser import get_parser
 from otter.generate.autograder import main as autograder
-from otter.generate.run_autograder import main as run_autograder
 from otter.generate.autograder import main as autograder
 from otter.generate.token import APIClient
+from otter.run.run_autograder import main as run_autograder
 
 from .. import TestCase
 
-parser = get_parser()
-
 client = APIClient('token1')
 
 # mock input
